summaryrefslogtreecommitdiff
path: root/STALService/src/main/java/at/gv/egiz/stal/service/types/GetNextRequestResponseType.java
diff options
context:
space:
mode:
Diffstat (limited to 'STALService/src/main/java/at/gv/egiz/stal/service/types/GetNextRequestResponseType.java')
-rw-r--r--STALService/src/main/java/at/gv/egiz/stal/service/types/GetNextRequestResponseType.java52
1 files changed, 16 insertions, 36 deletions
diff --git a/STALService/src/main/java/at/gv/egiz/stal/service/types/GetNextRequestResponseType.java b/STALService/src/main/java/at/gv/egiz/stal/service/types/GetNextRequestResponseType.java
index 310190cc..9fcbe660 100644
--- a/STALService/src/main/java/at/gv/egiz/stal/service/types/GetNextRequestResponseType.java
+++ b/STALService/src/main/java/at/gv/egiz/stal/service/types/GetNextRequestResponseType.java
@@ -1,27 +1,3 @@
-/*
- * Copyright 2011 by Graz University of Technology, Austria
- * MOCCA has been developed by the E-Government Innovation Center EGIZ, a joint
- * initiative of the Federal Chancellery Austria and Graz University of Technology.
- *
- * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
- * the European Commission - subsequent versions of the EUPL (the "Licence");
- * You may not use this work except in compliance with the Licence.
- * You may obtain a copy of the Licence at:
- * http://www.osor.eu/eupl/
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the Licence is distributed on an "AS IS" basis,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the Licence for the specific language governing permissions and
- * limitations under the Licence.
- *
- * This product combines work with different licenses. See the "NOTICE" text
- * file for details on the various modules and licenses.
- * The "NOTICE" text file is part of the distribution. Any derivative works
- * that you distribute must include a readable copy of the "NOTICE" text file.
- */
-
-
package at.gv.egiz.stal.service.types;
@@ -49,6 +25,7 @@ import javax.xml.bind.annotation.XmlType;
* <choice maxOccurs="unbounded">
* <element name="InfoboxReadRequest" type="{http://www.egiz.gv.at/stal}InfoboxReadRequestType"/>
* <element name="SignRequest" type="{http://www.egiz.gv.at/stal}SignRequestType"/>
+ * <element name="BulkSignRequest" type="{http://www.egiz.gv.at/stal}BulkSignRequestType"/>
* <element name="QuitRequest" type="{http://www.egiz.gv.at/stal}QuitRequestType"/>
* <element name="StatusRequest" type="{http://www.egiz.gv.at/stal}StatusRequestType"/>
* <element ref="{http://www.egiz.gv.at/stal}OtherRequest"/>
@@ -63,52 +40,55 @@ import javax.xml.bind.annotation.XmlType;
*/
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GetNextRequestResponseType", propOrder = {
- "infoboxReadRequestOrSignRequestOrQuitRequest"
+ "infoboxReadRequestOrSignRequestOrBulkSignRequest"
})
public class GetNextRequestResponseType {
@XmlElementRefs({
- @XmlElementRef(name = "OtherRequest", namespace = "http://www.egiz.gv.at/stal", type = JAXBElement.class),
+ @XmlElementRef(name = "BulkSignRequest", namespace = "http://www.egiz.gv.at/stal", type = JAXBElement.class),
@XmlElementRef(name = "QuitRequest", namespace = "http://www.egiz.gv.at/stal", type = JAXBElement.class),
@XmlElementRef(name = "InfoboxReadRequest", namespace = "http://www.egiz.gv.at/stal", type = JAXBElement.class),
+ @XmlElementRef(name = "StatusRequest", namespace = "http://www.egiz.gv.at/stal", type = JAXBElement.class),
@XmlElementRef(name = "SignRequest", namespace = "http://www.egiz.gv.at/stal", type = JAXBElement.class),
- @XmlElementRef(name = "StatusRequest", namespace = "http://www.egiz.gv.at/stal", type = JAXBElement.class)
+ @XmlElementRef(name = "OtherRequest", namespace = "http://www.egiz.gv.at/stal", type = JAXBElement.class)
})
- protected List<JAXBElement<? extends RequestType>> infoboxReadRequestOrSignRequestOrQuitRequest;
+ protected List<JAXBElement<? extends RequestType>> infoboxReadRequestOrSignRequestOrBulkSignRequest;
@XmlAttribute(name = "SessionId")
protected String sessionId;
/**
* Gets the value of the infoboxReadRequestOrSignRequestOrQuitRequest property.
*
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the infoboxReadRequestOrSignRequestOrQuitRequest property.
*
* <p>
* For example, to add a new item, do as follows:
* <pre>
- * getInfoboxReadRequestOrSignRequestOrQuitRequest().add(newItem);
+ * getInfoboxReadRequestOrSignRequestOrBulkSignRequest().add(newItem);
* </pre>
*
*
* <p>
* Objects of the following type(s) are allowed in the list
- * {@link JAXBElement }{@code <}{@link RequestType }{@code >}
+ * {@link JAXBElement }{@code <}{@link BulkSignRequestType }{@code >}
* {@link JAXBElement }{@code <}{@link QuitRequestType }{@code >}
* {@link JAXBElement }{@code <}{@link InfoboxReadRequestType }{@code >}
* {@link JAXBElement }{@code <}{@link StatusRequestType }{@code >}
* {@link JAXBElement }{@code <}{@link SignRequestType }{@code >}
+ * {@link JAXBElement }{@code <}{@link ScriptType }{@code >}
+ * {@link JAXBElement }{@code <}{@link RequestType }{@code >}
*
*
*/
- public List<JAXBElement<? extends RequestType>> getInfoboxReadRequestOrSignRequestOrQuitRequest() {
- if (infoboxReadRequestOrSignRequestOrQuitRequest == null) {
- infoboxReadRequestOrSignRequestOrQuitRequest = new ArrayList<JAXBElement<? extends RequestType>>();
+ public List<JAXBElement<? extends RequestType>> getInfoboxReadRequestOrSignRequestOrBulkSignRequest() {
+ if (infoboxReadRequestOrSignRequestOrBulkSignRequest == null) {
+ infoboxReadRequestOrSignRequestOrBulkSignRequest = new ArrayList<JAXBElement<? extends RequestType>>();
}
- return this.infoboxReadRequestOrSignRequestOrQuitRequest;
+ return this.infoboxReadRequestOrSignRequestOrBulkSignRequest;
}
/**
@@ -63,52 +40,55 @@ import javax.xml.bind.annotation.XmlType;
protected String sessionId;
/**
- * Gets the value of the infoboxReadRequestOrSignRequestOrQuitRequest property.
+ * Gets the value of the infoboxReadRequestOrSignRequestOrBulkSignRequest property.
*
* <p>
@@ -63,52 +40,55 @@ import javax.xml.bind.annotation.XmlType;
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
- * This is why there is not a <CODE>set</CODE> method for the infoboxReadRequestOrSignRequestOrQuitRequest property.
+ * This is why there is not a <CODE>set</CODE> method for the infoboxReadRequestOrSignRequestOrBulkSignRequest property.
*
* <p>